@@ -15,10 +15,13 @@
 # * name comes from http://www.thefreedictionary.com/cleave      #
 ##################################################################
 #                                                                # 
-# last changed in version = '2.4-2'                              #
+# last changed in version = '2.4-3'                              #
 #                                                                # 
 ##################################################################
 
+pathReaver=/home/user/.reaver
+
+
 [ "$(whoami)" != 'root' ] && ( echo you are using a non-privileged account; exit 1 )
 
 #push options directly
@@ -56,7 +59,8 @@ if [ "$1" == 'getWlanInformation' ]; then
     if [ -f $2/wlanInfo-01.csv ]; then rm $2/wlanInfo-* ; fi
     airodump-ng -w $2/wlanInfo wlan0 & sleep $3 && kill $!
     if [ -f /usr/bin/walsh ]; then 
-       walsh -f $2/wlanInfo-01.cap -C -o /home/user/.reaver/wpsInfo.txt
+       if [ -f $pathReaver/wpsInfo.txt ]; then rm $pathReaver/wpsInfo.txt ; fi
+       walsh -f $2/wlanInfo-01.cap -C -o $pathReaver/wpsInfo.txt
     fi
 fi 
 
@@ -120,10 +124,6 @@ if [ "$1" == 'decryptWEP' ]; then
     aircrack-ng -l $2/keys/$3.txt $2/capturedData/WEP/$4
 fi 
 
-if  [ "$1" == 'wpscrack' ]; then 
-    /opt/cleven/wpscrack.py --iface wlan0 --client $2 --bssid $3 --ssid $4 -v 
-fi 
-
 if  [ "$1" == 'reaver' ]; then 
     reaver -i wlan0 -b $2 -c $3 -e $4 -a -E -vv 
 fi 
@@ -133,9 +133,9 @@ if  [ "$1" == 'walsh' ]; then
 fi 
 
 if  [ "$1" == 'copyReaver' ]; then 
-    cp -pr $2/reaver $3 && chmod 755 $3/reaver && ln -s $3/reaver /usr/bin/reaver
+    cp -pr $2/reaver $3 && chmod 755 $3/reaver && if [ -f /usr/bin/reaver ]; then rm /usr/bin/reaver; fi && ln -s $3/reaver /usr/bin/reaver
 fi 
 
 if  [ "$1" == 'copyWalsh' ]; then 
-    cp -pr $2/walsh $3 && chmod 755 $3/walsh && ln -s $3/walsh /usr/bin/walsh
-    fi 
+    cp -pr $2/walsh $3 && chmod 755 $3/walsh && if [ -f /usr/bin/walsh ]; then rm /usr/bin/walsh; fi && ln -s $3/walsh /usr/bin/walsh
+fi 
